summaryrefslogtreecommitdiffstats
path: root/kalzium/src/timewidget_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalzium/src/timewidget_impl.h')
-rw-r--r--kalzium/src/timewidget_impl.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kalzium/src/timewidget_impl.h b/kalzium/src/timewidget_impl.h
index 65030da1..b728b435 100644
--- a/kalzium/src/timewidget_impl.h
+++ b/kalzium/src/timewidget_impl.h
@@ -22,13 +22,14 @@
class TimeWidgetIMPL : public TimeWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* @param parent The parent of this widget
* @param name The name of this widget
*/
- TimeWidgetIMPL( TQWidget *parent = 0, const char* name = 0 );
+ TimeWidgetIMPL( TQWidget *tqparent = 0, const char* name = 0 );
public slots:
/**
@@ -22,13 +22,14 @@
public:
/**
- * @param parent The parent of this widget
+ * @param tqparent The tqparent of this widget
* @param name The name of this widget
*/